"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// importing this solves issues with __awaiter not defined using await in Android HeadlessTask
require("nativescript-tslib");
var common_1 = require("./common");
var emptyFn = function () { };
var app = require("application");
var Fetch = com.transistorsoft.tsbackgroundfetch.BackgroundFetch;
var FetchConfig = com.transistorsoft.tsbackgroundfetch.BackgroundFetchConfig;
var BackgroundFetch = /** @class */ (function (_super) {
    __extends(BackgroundFetch, _super);
    function BackgroundFetch() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BackgroundFetch.registerHeadlessTask = function (callback) {
        this.headlessTask = callback;
    };
    BackgroundFetch.invokeHeadlessTask = function () {
        if (!this.headlessTask) {
            console.log('[BackgroundFetch] invokeHeadlessTask ERROR - headlessTask is null.  Did you BackgroundFetch.registerHeadlessTask(myTask) in your app.ts?');
            return false;
        }
        this.headlessTask();
        return true;
    };
    BackgroundFetch.configure = function (params, success, failure) {
        var builder = new FetchConfig.Builder();
        if (typeof (params.minimumFetchInterval) === 'number') {
            builder.setMinimumFetchInterval(params.minimumFetchInterval);
        }
        if (typeof (params.stopOnTerminate) === 'boolean') {
            builder.setStopOnTerminate(params.stopOnTerminate);
        }
        if (typeof (params.forceReload) === 'boolean') {
            builder.setForceReload(params.forceReload);
        }
        if (typeof (params.startOnBoot) === 'boolean') {
            builder.setStartOnBoot(params.startOnBoot);
        }
        if (params.enableHeadless === true) {
            builder.setJobService('com.transistorsoft.backgroundfetch.HeadlessJobService');
        }
        var adapter = this.getAdapter();
        var callback = new Fetch.Callback({
            onFetch: success
        });
        adapter.configure(builder.build(), callback);
        if (this.isForceReload) {
            callback.onFetch();
        }
    };
    BackgroundFetch.start = function (success, failure) {
        success = success || emptyFn;
        var adapter = this.getAdapter();
        adapter.start();
        success();
    };
    BackgroundFetch.stop = function (success, failure) {
        success = success || emptyFn;
        var adapter = this.getAdapter();
        adapter.stop();
        success();
    };
    BackgroundFetch.finish = function (result) {
        var adapter = this.getAdapter();
        adapter.finish();
    };
    BackgroundFetch.status = function (success) { };
    BackgroundFetch.init = function () {
        if (!app.android.startActivity || (this.intent !== null)) {
            return;
        }
        this.intent = app.android.startActivity.getIntent();
        var action = this.intent.getAction();
        if ((action != null) && (Fetch.ACTION_FORCE_RELOAD.toUpperCase() === action)) {
            this.isForceReload = true;
            app.android.startActivity.moveTaskToBack(true);
        }
    };
    BackgroundFetch.getAdapter = function () {
        if (!this.intent) {
            this.init();
        }
        return Fetch.getInstance(app.android.context.getApplicationContext());
    };
    BackgroundFetch.isForceReload = false;
    return BackgroundFetch;
}(common_1.AbstractBackgroundFetch));
exports.BackgroundFetch = BackgroundFetch;
